=======================
Reliability of code
=======================

Testing the code is a crucial step in ensuring that this package
can be used without having second thoughts about the implementation
details. At the same time, several tests contain assumptions that 
may or may not be in line with the requirements of a specific organisation.


The code has been tested using these options (in the order of importance):
    - Unit tests using SAS for creating test cases
    - Unit tests using the most popular R packages
    - Unit tests using implementation in Excel 

All unit tests are availble in the github repo (/test folder).

Please note that as of this update not all unit tests have been implemented.







  
  

